MoireTools

Enum MoireTools 

pub enum MoireTools {
    HelpTool(HelpTool),
    CutFreshTool(CutFreshTool),
    WaitEdgesTool(WaitEdgesTool),
    WaitChainsTool(WaitChainsTool),
    DeadlockCandidatesTool(DeadlockCandidatesTool),
    EntityTool(EntityTool),
    ChannelStateTool(ChannelStateTool),
    TaskStateTool(TaskStateTool),
    SourceContextTool(SourceContextTool),
    BacktraceTool(BacktraceTool),
    DiffSnapshotsTool(DiffSnapshotsTool),
}

Variants



HelpTool(HelpTool)



CutFreshTool(CutFreshTool)



WaitEdgesTool(WaitEdgesTool)



WaitChainsTool(WaitChainsTool)



DeadlockCandidatesTool(DeadlockCandidatesTool)



EntityTool(EntityTool)



ChannelStateTool(ChannelStateTool)



TaskStateTool(TaskStateTool)



SourceContextTool(SourceContextTool)



BacktraceTool(BacktraceTool)



DiffSnapshotsTool(DiffSnapshotsTool)

Implementations

Source

impl MoireTools

Returns the name of the tool as a String

pub fn tool_name(&self) -> String

pub fn tools() -> Vec<Tool>

Returns a vector containing instances of all supported tools