SourceContextTool

Struct SourceContextTool 

pub struct SourceContextTool {
    pub snapshot_id: Option<i64>,
    pub frame_ids: Vec<u64>,
    pub format: String,
}

Fields

snapshot_id: Option<i64>frame_ids: Vec<u64>format: String

Implementations

Source

impl SourceContextTool

pub fn tool_name() -> String

Returns the name of the tool as a String.

pub fn request_params() -> CallToolRequestParams

Returns a CallToolRequestParams initialized with the current tool’s name.

You can further customize the request by adding arguments or other attributes using the builder pattern. For example:

let args = serde_json::Map::new();
let task_meta = TaskMetadata{ttl: Some(200)}

let params: CallToolRequestParams = MyTool::request_params()
    .with_arguments(args)
    .with_task(task_meta);
Returns

A CallToolRequestParams with the tool name set.

pub fn tool() -> Tool

Constructs and returns a rust_mcp_schema::Tool instance.

The tool includes the name, description, input schema, meta, and title derived from the struct’s attributes.

Source

impl SourceContextTool